package Whelk::ResourceMeta;
$Whelk::ResourceMeta::VERSION = '0.99_01'; # TRIAL
$Whelk::ResourceMeta::VERSION = '0.9901';
use Kelp::Base;

attr name => sub { $_[0]->config->{name} // $_[0]->class };
attr class => undef;
attr config => sub { {} };

1;

