package Whelk::Formatter::JSON;
$Whelk::Formatter::JSON::VERSION = '0.99_01'; # TRIAL
$Whelk::Formatter::JSON::VERSION = '0.9901';
use Kelp::Base 'Whelk::Formatter';

attr response_format => sub { 'json' };

1;

